@@ -1,23 +1,25 @@
-/* $Id: server.c,v 1.9 1998/10/26 10:38:50 martin Exp $ */
+/* $Id: server.c,v 1.11 1999/02/23 11:43:44 martin Exp $ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #include "daemon.h"
 
@@ -28,6 +30,8 @@ glibtop *glibtop_global_server = &_glibtop_global_server;
 #include <glibtop/union.h>
 #include <glibtop/sysdeps.h>
 
+#include <sys/utsname.h>
+
 const unsigned long glibtop_server_features =
 GLIBTOP_SUID_CPU +
 GLIBTOP_SUID_MEM +
@@ -56,13 +60,26 @@ GLIBTOP_SUID_PPP;
 int
 main(int argc, char *argv[])
 {
-	/* !!! WE ARE ROOT HERE - CHANGE WITH CAUTION !!! */
-
+	struct utsname uts;
 	int uid, euid, gid, egid;
 
+	/* !!! WE ARE ROOT HERE - CHANGE WITH CAUTION !!! */
+
 	uid = getuid (); euid = geteuid ();
 	gid = getgid (); egid = getegid ();
 
+	if (uname (&uts)) _exit (1);
+
+	if (strcmp (uts.sysname, LIBGTOP_COMPILE_SYSTEM) ||
+	    strcmp (uts.release, LIBGTOP_COMPILE_RELEASE) ||
+	    strcmp (uts.machine, LIBGTOP_COMPILE_MACHINE)) {
+		fprintf (stderr, "Can only run on %s %s %s\n",
+			 LIBGTOP_COMPILE_SYSTEM,
+			 LIBGTOP_COMPILE_RELEASE,
+			 LIBGTOP_COMPILE_MACHINE);
+		_exit (1);
+	}
+	
 	glibtop_init_p (glibtop_global_server, 0, 0);
 
 	if (setreuid (euid, uid)) _exit (1);
