@@ -1,23 +1,25 @@
-/* $Id: prockernel.c,v 1.15 1998/12/06 13:02:02 martin Exp $ */
+/* $Id: prockernel.c,v 1.18 1999/02/23 11:44:09 martin Exp $ */
+
+/* Copyright (C) 1998 Joshua Sled
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Joshua Sled <jsled@xcf.berkeley.edu>, July 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #include <glibtop.h>
 #include <glibtop/error.h>
@@ -39,6 +41,7 @@
 
 #include <unistd.h>
 #include <fcntl.h>
+#include <osreldate.h>
 
 static const unsigned long _glibtop_sysdeps_proc_kernel_pstats =
 (1 << GLIBTOP_PROC_KERNEL_MIN_FLT) +
@@ -146,17 +149,14 @@ glibtop_get_proc_kernel_p (glibtop *server,
 		       (unsigned long) &u_addr->u_pcb,
 		       (char *) &pcb, sizeof (pcb)) == sizeof (pcb))
 		{
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
-
-			/* Sorry, don't know how to get it for
-			 * FreeBSD 3.0 at the moment.
-			 */
-
-#elif (defined __FreeBSD__)
+#ifdef __FreeBSD__
+#if (__FreeBSD_version >= 300003)
+			buf->kstk_esp = (u_int64_t) pcb.pcb_esp;
+			buf->kstk_eip = (u_int64_t) pcb.pcb_eip;
+#else
 			buf->kstk_esp = (u_int64_t) pcb.pcb_ksp;
 			buf->kstk_eip = (u_int64_t) pcb.pcb_pc;
-			
-			buf->flags |= _glibtop_sysdeps_proc_kernel_pcb;
+#endif
 #else
 			buf->kstk_esp = (u_int64_t) pcb.pcb_tss.tss_esp0;
 			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.__tss_eip;
