@@ -1,23 +1,25 @@
-/* $Id: procmap.c,v 1.6 1998/12/06 11:08:10 martin Exp $ */
+/* $Id: procmap.c,v 1.10 1999/02/23 12:58:15 martin Exp $ */
+
+/* Copyright (C) 1998 Joshua Sled
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Joshua Sled <jsled@xcf.berkeley.edu>, July 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #include <glibtop.h>
 #include <glibtop/error.h>
@@ -138,8 +140,13 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 		}
 
 #ifdef __FreeBSD__
-		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
+#if __FreeBSD__ >= 4
+		if (entry.eflags & (MAP_ENTRY_IS_SUB_MAP))
 			continue;
+#else
+ 		if (entry.eflags & (MAP_ENTRY_IS_A_MAP|MAP_ENTRY_IS_SUB_MAP))
+ 			continue;
+#endif
 #else
 		if (entry.is_a_map || entry.is_sub_map)
 			continue;
