@@ -1,24 +1,27 @@
-/* $Id: proctime.c,v 1.9 1998/11/17 23:15:12 martin Exp $ */
+/* $Id: proctime.c,v 1.12 1999/02/23 11:44:17 martin Exp $ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
+#include <osreldate.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proctime.h>
@@ -59,7 +62,10 @@ calcru(p, up, sp, ip)
 {
 	quad_t totusec;
 	u_quad_t u, st, ut, it, tot;
-	long sec, usec;
+#if (__FreeBSD_version < 300003)
+        long sec, usec;
+#endif
+        struct timeval tv;
 
 	st = p->p_sticks;
 	ut = p->p_uticks;
@@ -71,7 +77,7 @@ calcru(p, up, sp, ip)
 		tot = 1;
 	}
 
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+#if (defined __FreeBSD__) && (__FreeBSD_version >= 300003)
 
 	/* This was changed from a `struct timeval' into a `u_int64_t'
 	 * on FreeBSD 3.0 and renamed p_rtime -> p_runtime.
@@ -83,13 +89,14 @@ calcru(p, up, sp, ip)
 	usec = p->p_rtime.tv_usec;
 
 	totusec = (quad_t)sec * 1000000 + usec;
+#endif
+
 	if (totusec < 0) {
 		/* XXX no %qd in kernel.  Truncate. */
 		fprintf (stderr, "calcru: negative time: %ld usec\n",
 			 (long)totusec);
 		totusec = 0;
 	}
-#endif
 
 
 	u = totusec;
@@ -171,7 +178,7 @@ glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 
 	glibtop_suid_leave (server);
 
-#if (defined __FreeBSD__) && (__FreeBSD_version >= 300000)
+#if (defined __FreeBSD__) && (__FreeBSD_version >= 300003)
 	buf->rtime = pinfo [0].kp_proc.p_runtime;
 #else
 	buf->rtime = tv2sec (pinfo [0].kp_proc.p_rtime);
